'use strict'
path = require('path')
webpack = require('webpack')
autoprefixer = require('autoprefixer')
extractTextPlugin = require('extract-text-webpack-plugin')

module.exports =
  debug: false
  resolve:
    root: __dirname
    modulesDirectories: ['node_modules']
    extensions: [
      ''
      '.coffee'
      '.js'
    ]
    alias:
      'underscore': 'lodash'
  entry:
    main: [
      'tether'
      'font-awesome-loader'
      'bootstrap-loader/extractStyles'
      './src/main/coffee/main'
    ]
    vendor: [
      'consolelog'
      'es5-shim'
      'es5-shim/es5-sham'
      'es6-shim'
      'es6-shim/es6-sham'
      'json3'
      'html5shiv'
      'html5shiv/dist/html5shiv-printshiv'
    ]
  output:
    path: path.join(__dirname, './assets')
    filename: '[name].js'
#    filename: "[name]-[chunkhash].js"
#    chunkFilename: "[name]-[chunkhash].js"
    publicPath: '/assets/'
    pathinfo: false
  plugins: [
    new (extractTextPlugin)('[name].css', { allChunks: true })
    new (webpack.NoErrorsPlugin)
    new (webpack.ProvidePlugin)(
      'window.Tether': 'tether'
    )
#    new (webpack.optimize.CommonsChunkPlugin)(
#      name: 'vendor',
#      chunks: ['vendor'],
#      filename: 'vendor.js',
#      minChunks: Infinity,
#      async: true
#    )
    new (webpack.optimize.DedupePlugin),
    new (webpack.optimize.OccurrenceOrderPlugin)(true)
    new (webpack.optimize.UglifyJsPlugin)(
      mangle: true
      output:
        comments: false
      compress:
        warnings: false
    )
  ]
  module:
    preLoaders: [
      test: /\.coffee$/
      loader: 'eslint'
      exclude: /node_modules/
    ]
    loaders: [
      test: /\.coffee$/
      loader: 'coffee-loader'
    ,
      test: /\.scss$/
      loader: extractTextPlugin.extract('style', 'css!postcss!sass')
    ,
      test: /\.css$/
      exclude: /.*\.min.css/
      loader: extractTextPlugin.extract('style', 'css!postcss')
    ,
      test: /\.png$/
      loader: 'url?limit=8192&mimetype=image/png'
    ,
      test: /\.jpe?g$/
      loader: 'url?limit=8192&mimetype=image/jpg'
    ,
      test: /\.gif$/
      loader: 'url?limit=8192&mimetype=image/gif'
    ,
      test: /\.svg(\?v=\d+\.\d+\.\d+)?$/
      loader: 'url?limit=8192&mimetype=image/svg+xml'
    ,
      test: /\.woff2(\?v=\d+\.\d+\.\d+)?$/
      loader: 'url?limit=8192&mimetype=application/font-woff2'
    ,
      test: /\.woff(\?v=\d+\.\d+\.\d+)?$/
      loader: 'url?limit=8192&mimetype=application/font-woff'
    ,
      test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/
      loader: 'url?limit=8192&mimetype=application/octet-stream'
    ,
      test: /\.eot(\?v=\d+\.\d+\.\d+)?$/
      loader: 'file'
    ,
      test: /bootstrap-sass[\/\\]assets[\/\\]javascripts[\/\\]/
      loader: 'imports?jQuery=jquery'
    ]
  postcss: [ autoprefixer ]
  eslint:
    emitErrors: true
    reporter: (results) ->
      results.map((result) ->
        result.messages.map((msg) ->
          ' ' + msg.message + '(' + msg.ruleId + ')' + ' @ line ' + msg.line + ' column ' + msg.column + ' - ' + (if msg.fatal then 'fatal, ' else '') + 'severity: ' + msg.severity
        ).join '\n'
      ).join '\n'
